==> joplin_3.4.4+ds.orig.tar.xz: joplin-3.4.4/packages/app-mobile/contentScripts/markdownEditorBundle/useWebViewSetup.ts <==
import shim from '@joplin/lib/shim';
import { EditorProcessApi, EditorProps as EditorOptions, SelectionRange, MainProcessApi } from './types';
import { SetUpResult } from '../types';
import { SearchState } from '@joplin/editor/types';
import { RefObject, useEffect, useMemo, useRef } from 'react';
import { OnMessageEvent, WebViewControl } from '../../components/ExtendedWebView/types';
import { EditorEvent } from '@joplin/editor/events';
import Logger from '@joplin/utils/Logger';
import RNToWebViewMessenger from '../../utils/ipc/RNToWebViewMessenger';

const logger = Logger.create('markdownEditor');

interface Props {
	editorOptions: EditorOptions;
	initialSelection: SelectionRange;
	noteHash: string;
	globalSearch: string;
	onEditorEvent: (event: EditorEvent)=> void;
	onAttachFile: (mime: string, base64: string)=> void;

	webviewRef: RefObject<WebViewControl>;
}

const defaultSearchState: SearchState = {
	useRegex: false,
	caseSensitive: false,

	searchText: '',
	replaceText: '',
	dialogVisible: false,
};

const useWebViewSetup = ({
	editorOptions, initialSelection, noteHash, globalSearch, webviewRef, onEditorEvent, onAttachFile,
}: Props): SetUpResult<EditorProcessApi> => {
	const setInitialSelectionJs = initialSelection ? `
		cm.select(${initialSelection.start}, ${initialSelection.end});
		cm.execCommand('scrollSelectionIntoView');
	` : '';
	const jumpToHashJs = noteHash ? `
		cm.jumpToHash(${JSON.stringify(noteHash)});
	` : '';
	const setInitialSearchJs = globalSearch ? `
		cm.setSearchState(${JSON.stringify({
		...defaultSearchState,
		searchText: globalSearch,
	})})
	` : '';

	const injectedJavaScript = useMemo(() => `
		if (!window.cm) {
			${shim.injectedJs('markdownEditorBundle')};
			markdownEditorBundle.setUpLogger();

			window.cm = markdownEditorBundle.initializeEditor(
				${JSON.stringify(editorOptions)}
			);

			${jumpToHashJs}
			// Set the initial selection after jumping to the header -- the initial selection,
			// if specified, should take precedence.
			${setInitialSelectionJs}
			${setInitialSearchJs}

			window.onresize = () => {
				cm.execCommand('scrollSelectionIntoView');
			};
		}
	`, [jumpToHashJs, setInitialSearchJs, setInitialSelectionJs, editorOptions]);

	// Scroll to the new hash, if it changes.
	const isFirstScrollRef = useRef(true);
	useEffect(() => {
		// The first "jump to header" is handled during editor setup and shouldn't
		// be handled a second time:
		if (isFirstScrollRef.current) {
			isFirstScrollRef.current = false;
			return;
		}
		if (jumpToHashJs && webviewRef.current) {
			webviewRef.current.injectJS(jumpToHashJs);
		}
	}, [jumpToHashJs, webviewRef]);

	const onEditorEventRef = useRef(onEditorEvent);
	onEditorEventRef.current = onEditorEvent;

	const onAttachRef = useRef(onAttachFile);
	onAttachRef.current = onAttachFile;

	const editorMessenger = useMemo(() => {
		const localApi: MainProcessApi = {
			async onEditorEvent(event) {
				onEditorEventRef.current(event);
			},
			async logMessage(message) {
				logger.debug('CodeMirror:', message);
			},
			async onPasteFile(type, data) {
				onAttachRef.current(type, data);
			},
		};
		const messenger = new RNToWebViewMessenger<MainProcessApi, EditorProcessApi>(
			'markdownEditor', webviewRef, localApi,
		);
		return messenger;
	}, [webviewRef]);

	const webViewEventHandlers = useMemo(() => {
		return {
			onLoadEnd: () => {
				editorMessenger.onWebViewLoaded();
			},
			onMessage: (event: OnMessageEvent) => {
				editorMessenger.onWebViewMessage(event);
			},
		};
	}, [editorMessenger]);

	const api = useMemo(() => {
		return editorMessenger.remoteApi;
	}, [editorMessenger]);

	const editorSettings = editorOptions.settings;
	useEffect(() => {
		api.editor.updateSettings(editorSettings);
	}, [api, editorSettings]);

	return useMemo(() => ({
		pageSetup: {
			js: injectedJavaScript,
			css: '',
		},
		api,
		webViewEventHandlers,
	}), [injectedJavaScript, api, webViewEventHandlers]);
};

export default useWebViewSetup;

==> joplin_3.4.5+ds.orig.tar.xz: joplin-3.4.5/packages/app-mobile/contentScripts/markdownEditorBundle/useWebViewSetup.ts <==
import shim from '@joplin/lib/shim';
import { EditorProcessApi, EditorProps as EditorOptions, SelectionRange, MainProcessApi } from './types';
import { SetUpResult } from '../types';
import { SearchState } from '@joplin/editor/types';
import { RefObject, useEffect, useMemo, useRef } from 'react';
import { OnMessageEvent, WebViewControl } from '../../components/ExtendedWebView/types';
import { EditorEvent } from '@joplin/editor/events';
import Logger from '@joplin/utils/Logger';
import RNToWebViewMessenger from '../../utils/ipc/RNToWebViewMessenger';
import Resource from '@joplin/lib/models/Resource';
import { parseResourceUrl } from '@joplin/lib/urlUtils';
const { isImageMimeType } = require('@joplin/lib/resourceUtils');

const logger = Logger.create('markdownEditor');

interface Props {
	editorOptions: EditorOptions;
	initialSelection: SelectionRange;
	noteHash: string;
	globalSearch: string;
	onEditorEvent: (event: EditorEvent)=> void;
	onAttachFile: (mime: string, base64: string)=> void;

	webviewRef: RefObject<WebViewControl>;
}

const defaultSearchState: SearchState = {
	useRegex: false,
	caseSensitive: false,

	searchText: '',
	replaceText: '',
	dialogVisible: false,
};

const useWebViewSetup = ({
	editorOptions, initialSelection, noteHash, globalSearch, webviewRef, onEditorEvent, onAttachFile,
}: Props): SetUpResult<EditorProcessApi> => {
	const setInitialSelectionJs = initialSelection ? `
		cm.select(${initialSelection.start}, ${initialSelection.end});
		cm.execCommand('scrollSelectionIntoView');
	` : '';
	const jumpToHashJs = noteHash ? `
		cm.jumpToHash(${JSON.stringify(noteHash)});
	` : '';
	const setInitialSearchJs = globalSearch ? `
		cm.setSearchState(${JSON.stringify({
		...defaultSearchState,
		searchText: globalSearch,
	})})
	` : '';

	const injectedJavaScript = useMemo(() => `
		if (!window.cm) {
			const parentClassName = ${JSON.stringify(editorOptions.parentElementClassName)};
			const foundParent = document.getElementsByClassName(parentClassName).length > 0;

			// On Android, injectedJavaScript can be run multiple times, including once before the
			// document has loaded. To avoid logging an error each time the editor starts, don't throw
			// if the parent element can't be found:
			if (foundParent) {
				${shim.injectedJs('markdownEditorBundle')};
				markdownEditorBundle.setUpLogger();

				window.cm = markdownEditorBundle.initializeEditor(
					${JSON.stringify(editorOptions)}
				);

				${jumpToHashJs}
				// Set the initial selection after jumping to the header -- the initial selection,
				// if specified, should take precedence.
				${setInitialSelectionJs}
				${setInitialSearchJs}

				window.onresize = () => {
					cm.execCommand('scrollSelectionIntoView');
				};
			} else {
				console.log('No parent element found with class name ', parentClassName);
			}
		}
	`, [jumpToHashJs, setInitialSearchJs, setInitialSelectionJs, editorOptions]);

	// Scroll to the new hash, if it changes.
	const isFirstScrollRef = useRef(true);
	useEffect(() => {
		// The first "jump to header" is handled during editor setup and shouldn't
		// be handled a second time:
		if (isFirstScrollRef.current) {
			isFirstScrollRef.current = false;
			return;
		}
		if (jumpToHashJs && webviewRef.current) {
			webviewRef.current.injectJS(jumpToHashJs);
		}
	}, [jumpToHashJs, webviewRef]);

	const onEditorEventRef = useRef(onEditorEvent);
	onEditorEventRef.current = onEditorEvent;

	const onAttachRef = useRef(onAttachFile);
	onAttachRef.current = onAttachFile;

	const editorMessenger = useMemo(() => {
		const localApi: MainProcessApi = {
			async onEditorEvent(event) {
				onEditorEventRef.current(event);
			},
			async logMessage(message) {
				logger.debug('CodeMirror:', message);
			},
			async onPasteFile(type, data) {
				onAttachRef.current(type, data);
			},
			async onResolveImageSrc(src) {
				const url = parseResourceUrl(src);
				if (!url.itemId) return null;
				const item = await Resource.load(url.itemId);

				if (shim.mobilePlatform() === 'web') {
					// Maximum 6 MiB on web
					const maximumSize = 6 * 1024 * 1024;
					if (isImageMimeType(item.mime) && item.size < maximumSize) {
						const data = await shim.fsDriver().readFile(Resource.fullPath(item), 'base64');
						return `data:${item.mime};base64,${data}`;
					}
					return null;
				} else {
					return Resource.fullPath(item);
				}
			},
		};
		const messenger = new RNToWebViewMessenger<MainProcessApi, EditorProcessApi>(
			'markdownEditor', webviewRef, localApi,
		);
		return messenger;
	}, [webviewRef]);

	const webViewEventHandlers = useMemo(() => {
		return {
			onLoadEnd: () => {
				editorMessenger.onWebViewLoaded();
			},
			onMessage: (event: OnMessageEvent) => {
				editorMessenger.onWebViewMessage(event);
			},
		};
	}, [editorMessenger]);

	const api = useMemo(() => {
		return editorMessenger.remoteApi;
	}, [editorMessenger]);

	const editorSettings = editorOptions.settings;
	useEffect(() => {
		api.editor.updateSettings(editorSettings);
	}, [api, editorSettings]);

	return useMemo(() => ({
		pageSetup: {
			js: injectedJavaScript,
			css: '',
		},
		api,
		webViewEventHandlers,
	}), [injectedJavaScript, api, webViewEventHandlers]);
};

export default useWebViewSetup;
